@@ -5,6 +5,7 @@
 */
 
 #include "locationutil.h"
+#include "locationutil_p.h"
 
 #include <KItinerary/BoatTrip>
 #include <KItinerary/BusTrip>
@@ -15,12 +16,27 @@
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
 
+#include <KContacts/Address>
+
 #include <QDebug>
+#include <QUrl>
+#include <QUrlQuery>
 
 #include <cmath>
 
 using namespace KItinerary;
 
+KContacts::Address LocationUtil::toAddress(const PostalAddress &addr)
+{
+    KContacts::Address a;
+    a.setStreet(addr.streetAddress());
+    a.setPostalCode(addr.postalCode());
+    a.setLocality(addr.addressLocality());
+    a.setRegion(addr.addressRegion());
+    a.setCountry(addr.addressCountry());
+    return a;
+}
+
 bool LocationUtil::isLocationChange(const QVariant &res)
 {
     if (JsonLd::isA<RentalCarReservation>(res)) {
@@ -208,6 +224,30 @@ static QString applyTransliterations(const QString &s)
     return res;
 }
 
+static bool compareSpaceCaseInsenstive(const QString &lhs, const QString &rhs)
+{
+    auto lit = lhs.begin();
+    auto rit = rhs.begin();
+    while (true) {
+        while ((*lit).isSpace() && lit != lhs.end()) {
+            ++lit;
+        }
+        while ((*rit).isSpace() && rit != rhs.end()) {
+            ++rit;
+        }
+        if (lit == lhs.end() || rit == rhs.end()) {
+            break;
+        }
+        if ((*lit).toCaseFolded() != (*rit).toCaseFolded()) {
+            return false;
+        }
+        ++lit;
+        ++rit;
+    }
+
+    return lit == lhs.end() && rit == rhs.end();
+}
+
 static bool isSameLocationName(const QString &lhs, const QString &rhs, LocationUtil::Accuracy accuracy)
 {
     if (lhs.isEmpty() || rhs.isEmpty()) {
@@ -224,8 +264,8 @@ static bool isSameLocationName(const QString &lhs, const QString &rhs, LocationU
     const auto rhsNormalized = stripDiacritics(rhs);
     const auto lhsTransliterated = applyTransliterations(lhs);
     const auto rhsTransliterated = applyTransliterations(rhs);
-    if (lhsNormalized.compare(rhsNormalized, Qt::CaseInsensitive) == 0 || lhsNormalized.compare(rhsTransliterated, Qt::CaseInsensitive) == 0
-        || lhsTransliterated.compare(rhsNormalized, Qt::CaseInsensitive) == 0 || lhsTransliterated.compare(rhsTransliterated, Qt::CaseInsensitive) == 0) {
+    if (compareSpaceCaseInsenstive(lhsNormalized, rhsNormalized) || compareSpaceCaseInsenstive(lhsNormalized, rhsTransliterated)
+        || compareSpaceCaseInsenstive(lhsTransliterated, rhsNormalized) || compareSpaceCaseInsenstive(lhsTransliterated, rhsTransliterated)) {
         return true;
     }
 
@@ -292,3 +332,26 @@ bool LocationUtil::isSameLocation(const QVariant &lhs, const QVariant &rhs, Loca
 
     return isSameLocationName(name(lhs), name(rhs), accuracy);
 }
+
+QUrl LocationUtil::geoUri(const QVariant &location)
+{
+    QUrl url;
+    url.setScheme(QStringLiteral("geo"));
+
+    const auto geo = LocationUtil::geo(location);
+    if (geo.isValid()) {
+        url.setPath(QString::number(geo.latitude()) + QLatin1Char(',') + QString::number(geo.longitude()));
+        return url;
+    }
+
+    const auto addr = LocationUtil::address(location);
+    if (!addr.isEmpty()) {
+        url.setPath(QStringLiteral("0,0"));
+        QUrlQuery query;
+        query.addQueryItem(QStringLiteral("q"), toAddress(addr).formatted(KContacts::AddressFormatStyle::GeoUriQuery));
+        url.setQuery(query);
+        return url;
+    }
+
+    return {};
+}
