@@ -6,8 +6,6 @@
 
 #pragma once
 
-#include <config-kitinerary.h>
-
 #include "pdfimage.h"
 #include "pdfvectorpicture_p.h"
 
@@ -27,18 +25,14 @@ class PdfPagePrivate;
 class PdfImagePrivate : public QSharedData {
 public:
     QImage load();
-#ifdef HAVE_POPPLER
     QImage load(Stream *str, GfxImageColorMap *colorMap);
-#endif
 
     // pixel data
     int m_refNum = -1;
     int m_refGen = -1;
     QImage::Format m_format = QImage::Format_Invalid;
     PdfPagePrivate *m_page = nullptr;
-#ifdef HAVE_POPPLER
     std::unique_ptr<GfxImageColorMap> m_colorMap;
-#endif
 
     // vector data
     PdfVectorPicture m_vectorPicture;
