@@ -24,12 +24,21 @@ class KITINERARY_EXPORT Rct2Ticket
     Q_GADGET
     Q_PROPERTY(QDate firstDayOfValidity READ firstDayOfValidity)
     Q_PROPERTY(Type type READ type)
+    Q_PROPERTY(QString title READ title)
     Q_PROPERTY(QString passengerName READ passengerName)
+
     Q_PROPERTY(QDateTime outboundDepartureTime READ outboundDepartureTime)
     Q_PROPERTY(QDateTime outboundArrivalTime READ outboundArrivalTime)
     Q_PROPERTY(QString outboundDepartureStation READ outboundDepartureStation)
     Q_PROPERTY(QString outboundArrivalStation READ outboundArrivalStation)
     Q_PROPERTY(QString outboundClass READ outboundClass)
+
+    Q_PROPERTY(QDateTime returnDepartureTime READ returnDepartureTime)
+    Q_PROPERTY(QDateTime returnArrivalTime READ returnArrivalTime)
+    Q_PROPERTY(QString returnDepartureStation READ returnDepartureStation)
+    Q_PROPERTY(QString returnArrivalStation READ returnArrivalStation)
+    Q_PROPERTY(QString returnClass READ returnClass)
+
     Q_PROPERTY(QString trainNumber READ trainNumber)
     Q_PROPERTY(QString coachNumber READ coachNumber)
     Q_PROPERTY(QString seatNumber READ seatNumber)
@@ -61,10 +70,13 @@ public:
         Upgrade, ///< Update Document (UPG)
         Unknown ///< ticket type could not be detected, or ticket type not supported yet
     };
-    Q_ENUM(Type);
+    Q_ENUM(Type)
     /** Returns the ticket type. */
     Type type() const;
 
+    /** Name or title of the ticket. */
+    QString title() const;
+
     /** Name of the passenger this ticket is for. */
     QString passengerName() const;
 
@@ -79,6 +91,17 @@ public:
     /** Class of the outbound segment. */
     QString outboundClass() const;
 
+    /** Departure time of the return segment, if present. */
+    QDateTime returnDepartureTime() const;
+    /** Arrival time of the return segment, if present. */
+    QDateTime returnArrivalTime() const;
+    /** Departure station of the return segment, if present. */
+    QString returnDepartureStation() const;
+    /** Arrival station of the return segment, if present. */
+    QString returnArrivalStation() const;
+    /** Class of the return segment, if present. */
+    QString returnClass() const;
+
     /** Train number (for reservation tickets). */
     QString trainNumber() const;
     /** Coach number (for reservation tickets). */
